@@ -234,7 +234,7 @@
                       pcr =, pls =, plsTest =,PLS = data.frame(.ncomp = seq(1, min(dim(data)[2] - 1, len), by = 1)),
                       pam = pamTune(data, len),
                       knn = data.frame(.k = (5:((2 * len)+4))[(5:((2 * len)+4))%%2 > 0]),
-                      nb = data.frame(.usekernel = c(TRUE, FALSE)),
+                      nb = data.frame(.usekernel = c(TRUE, FALSE), .fL = 0),
                       multinom = data.frame(.decay = c(0, 10 ^ seq(-4, -1, length = len - 1))),
                       bagEarth =, bagFDA =, earth =,
                       earthTest =, mars =,
@@ -283,7 +283,7 @@
                       relaxo = relaxoGrid(data, len),
                       logitBoost = data.frame(.nIter =  floor((1:len) * 50)),
                       J48 = data.frame(.C = 0.25),
-                      M5Rules = data.frame(.pruned = c("Yes", "No")),
+                      M5Rules = data.frame(.pruned = c("Yes", "No"), .smoothed = "Yes"),
                       LMT = data.frame(.iter = (1:len) * 20),
                       JRip = data.frame(.NumOpt = 1:len),
                       superpc = expand.grid(.n.components = 1:3,
