@@ -13,11 +13,13 @@ trainControl <- function(method = "boot",
                          k = 5,
                          index = NULL,
                          workers = 1,
+                         predictionBounds = rep(FALSE, 2),
                          computeFunction = lapply,
                          computeArgs = NULL)
 {
   if(is.null(selectionFunction)) stop("null selectionFunction values not allowed")
   if(!(returnResamp %in% c("all", "final", "none"))) stop("incorrect value of returnResamp")
+  if(length(predictionBounds) > 0 && length(predictionBounds) != 2) stop("'predictionBounds' should be a logical or numeric vector of length 2")
   list(method = method,
        number = number,
        repeats = repeats,
@@ -33,6 +35,7 @@ trainControl <- function(method = "boot",
        k = k,
        index = index,
        workers = workers,
+       predictionBounds = predictionBounds,
        computeFunction = computeFunction,
        computeArgs = computeArgs)
 }
